@@ -7,25 +7,23 @@
 #include "calculator.h"
 
 #include "kalzium_debug.h"
-#include <QDialog>
 #include <QDialogButtonBox>
 #include <QIcon>
 #include <QPushButton>
 #include <QVBoxLayout>
 
-#include <KActionCollection>
 #include <KConfigGroup>
 #include <KHelpClient>
 #include <KLocalizedString>
 #include <KStandardAction>
 
-calculator::calculator(QWidget *parent) : QDialog(parent)
+calculator::calculator(QWidget *parent)
+    : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Chemical Calculator"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Help|QDialogButtonBox::Close, this);
-    QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Help | QDialogButtonBox::Close, this);
+    auto mainWidget = new QWidget(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &calculator::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &calculator::reject);
@@ -68,11 +66,10 @@ calculator::calculator(QWidget *parent) : QDialog(parent)
     ui.stack->addWidget(m_equationBalancer);
 #endif
     // Add an image to the file
-    ui.pic->setPixmap((QIcon::fromTheme(QStringLiteral("calculate"))).pixmap(128,128));
+    ui.pic->setPixmap((QIcon::fromTheme(QStringLiteral("calculate"))).pixmap(128, 128));
 
     // Connect the tree item selection signal to the corresponding slot
-    connect(ui.tree, &QTreeWidget::itemClicked, this,
-            &calculator::slotItemSelection);
+    connect(ui.tree, &QTreeWidget::itemClicked, this, &calculator::slotItemSelection);
 
     ui.tree->setCurrentItem(ui.tree->topLevelItem(0), 0, QItemSelectionModel::ToggleCurrent);
 
@@ -80,9 +77,7 @@ calculator::calculator(QWidget *parent) : QDialog(parent)
     connect(buttonBox->button(QDialogButtonBox::Help), &QPushButton::clicked, this, &calculator::slotHelp);
 }
 
-calculator :: ~calculator()
-{
-}
+calculator ::~calculator() = default;
 
 void calculator::slotItemSelection(QTreeWidgetItem *item)
 {
@@ -90,7 +85,7 @@ void calculator::slotItemSelection(QTreeWidgetItem *item)
         return;
     }
 
-    //DEBUG
+    // DEBUG
     qCDebug(KALZIUM_LOG) << "Item clicked: " << item->text(0);
 
     QString s = item->text(0);
@@ -107,10 +102,10 @@ void calculator::slotItemSelection(QTreeWidgetItem *item)
         // if the concentration calculator is selected, show the widget in the UI
         ui.stack->setCurrentWidget(m_concCalculator);
 
-    // The equation balancer needs FACILE library, if it's present HAVE_FACILE = 1
+        // The equation balancer needs FACILE library, if it's present HAVE_FACILE = 1
 #ifdef HAVE_FACILE
     } else if (!(s.compare(i18n("Equation Balancer")))) {
-    // If the equation balancer was selected, open it in the UI.
+        // If the equation balancer was selected, open it in the UI.
         ui.stack->setCurrentWidget(m_equationBalancer);
 #endif
 
@@ -121,7 +116,6 @@ void calculator::slotItemSelection(QTreeWidgetItem *item)
     }
 }
 
-
 void calculator::slotHelp()
 {
     KHelpClient::invokeHelp(QStringLiteral("tools.html#perf_calculation"), QStringLiteral("kalzium"));
