@@ -6,10 +6,11 @@
 
 #include "search.h"
 
-#include "element.h"
 #include "kalziumdataobject.h"
 
-Search::Search() : m_isActive(false), m_searchKind(Search::SearchAll)
+Search::Search()
+    : m_isActive(false)
+    , m_searchKind(Search::SearchAll)
 {
 }
 
@@ -28,36 +29,34 @@ bool Search::isActive() const
     return m_isActive;
 }
 
-const QList<Element*>& Search::foundElements() const
+const QList<Element *> &Search::foundElements() const
 {
     return m_foundElements;
 }
 
-bool Search::matches(Element* e) const
+bool Search::matches(Element *e) const
 {
     return m_foundElements.contains(e);
 }
 
 bool Search::matches(int el) const
 {
-    Element *element =  KalziumDataObject::instance()->element(el);
+    Element *element = KalziumDataObject::instance()->element(el);
     return matches(element);
 }
 
-void Search::doSearch(const QString& text, SearchKind kind)
+void Search::doSearch(const QString &text, SearchKind kind)
 {
     m_isActive = true;
     m_searchText = text;
     m_searchKind = kind;
-    QList<Element*> newresults;
+    QList<Element *> newresults;
     foreach (Element *e, KalziumDataObject::instance()->ElementList) {
         bool found = false;
-        if (!found
-            && e->dataAsString(ChemicalDataObject::name).contains(text, Qt::CaseInsensitive)) {
+        if (!found && e->dataAsString(ChemicalDataObject::name).contains(text, Qt::CaseInsensitive)) {
             found = true;
         }
-        if (!found
-            && e->dataAsString(ChemicalDataObject::symbol).contains(text, Qt::CaseInsensitive)) {
+        if (!found && e->dataAsString(ChemicalDataObject::symbol).contains(text, Qt::CaseInsensitive)) {
             found = true;
         }
         if (found) {
@@ -66,7 +65,7 @@ void Search::doSearch(const QString& text, SearchKind kind)
     }
     if (newresults != m_foundElements) {
         m_foundElements = newresults;
-        emit searchChanged();
+        Q_EMIT searchChanged();
     }
 }
 
@@ -78,6 +77,5 @@ void Search::resetSearch()
 
     m_foundElements.clear();
     m_isActive = false;
-    emit searchReset();
+    Q_EMIT searchReset();
 }
-
